@@ -1,6 +1,15 @@
 use strict;
 use warnings FATAL => 'all';
 
+package T::Upload::Image;
+use base 'HTML::Tested::Value::Upload';
+
+sub absorb_one_value {
+	my ($self, $root, $val, @path) = @_;
+	return unless $val->size;
+	$self->SUPER::absorb_one_value($root, $val, @path);
+}
+
 package T::Upload::DB;
 use base 'Apache::SWIT::DB::Base';
 __PACKAGE__->set_up_table('upt');
@@ -13,10 +22,10 @@ __PACKAGE__->ht_add_widget(::HTV, id => is_sealed => 1
 					=> cdbi_bind => 'Primary');
 __PACKAGE__->ht_add_widget(::HTV."::Upload", the_upload => cdbi_upload =>
 				'loid');
-__PACKAGE__->ht_add_widget(::HTV."::Upload", mime_upload =>
+__PACKAGE__->ht_add_widget('T::Upload::Image', mime_upload =>
 		cdbi_upload_with_mime => 'loid');
 __PACKAGE__->ht_add_widget(::HTV, loid => is_sealed => 1 => cdbi_bind => ''
-				, cdbi_readonly => 1);
+				, cdbi_readonly => 1, skip_undef => 1);
 __PACKAGE__->ht_add_widget(::HTV."::Form", form => default_value => 'u');
 __PACKAGE__->bind_to_class_dbi("T::Upload::DB");
 
